package com.goomood.phm.mapper;

import java.util.List;
import com.goomood.phm.domain.BasicSpeciality;

/**
 * 专业管理Mapper接口
 * 
 * @author goomood
 * @date 2024-11-16
 */
public interface BasicSpecialityMapper 
{
    /**
     * 查询专业管理
     * 
     * @param id 专业管理主键
     * @return 专业管理
     */
    public BasicSpeciality selectBasicSpecialityById(Long id);

    /**
     * 查询专业管理列表
     * 
     * @param basicSpeciality 专业管理
     * @return 专业管理集合
     */
    public List<BasicSpeciality> selectBasicSpecialityList(BasicSpeciality basicSpeciality);

    /**
     * 新增专业管理
     * 
     * @param basicSpeciality 专业管理
     * @return 结果
     */
    public int insertBasicSpeciality(BasicSpeciality basicSpeciality);

    /**
     * 修改专业管理
     * 
     * @param basicSpeciality 专业管理
     * @return 结果
     */
    public int updateBasicSpeciality(BasicSpeciality basicSpeciality);

    /**
     * 删除专业管理
     * 
     * @param id 专业管理主键
     * @return 结果
     */
    public int deleteBasicSpecialityById(Long id);

    /**
     * 批量删除专业管理
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteBasicSpecialityByIds(Long[] ids);
}
